==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeTLSConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ProbeTLSConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfig,io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfigBuilder>{
  public ProbeTLSConfigBuilder() {
    this(false);
  }
  public ProbeTLSConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new ProbeTLSConfig(), validationEnabled);
  }
  public ProbeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ProbeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ProbeTLSConfig(), validationEnabled);
  }
  public ProbeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfig instance) {
    this(fluent, instance, false);
  }
  public ProbeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCa(instance.getCa()); 
    fluent.withCert(instance.getCert()); 
    fluent.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    fluent.withKeySecret(instance.getKeySecret()); 
    fluent.withServerName(instance.getServerName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProbeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfig instance) {
    this(instance,false);
  }
  public ProbeTLSConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withCa(instance.getCa()); 
    this.withCert(instance.getCert()); 
    this.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    this.withKeySecret(instance.getKeySecret()); 
    this.withServerName(instance.getServerName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.ProbeTLSConfig build() {
    ProbeTLSConfig buildable = new ProbeTLSConfig(fluent.getCa(),fluent.getCert(),fluent.getInsecureSkipVerify(),fluent.getKeySecret(),fluent.getServerName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ProbeTLSConfigBuilder that = (ProbeTLSConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.1.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ProbeTLSConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ProbeTLSConfigBuilder extends ProbeTLSConfigFluentImpl<ProbeTLSConfigBuilder> implements VisitableBuilder<ProbeTLSConfig,ProbeTLSConfigBuilder>{
  public ProbeTLSConfigBuilder() {
    this(false);
  }
  public ProbeTLSConfigBuilder(Boolean validationEnabled) {
    this(new ProbeTLSConfig(), validationEnabled);
  }
  public ProbeTLSConfigBuilder(ProbeTLSConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public ProbeTLSConfigBuilder(ProbeTLSConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ProbeTLSConfig(), validationEnabled);
  }
  public ProbeTLSConfigBuilder(ProbeTLSConfigFluent<?> fluent,ProbeTLSConfig instance) {
    this(fluent, instance, false);
  }
  public ProbeTLSConfigBuilder(ProbeTLSConfigFluent<?> fluent,ProbeTLSConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withCa(instance.getCa()); 
    fluent.withCert(instance.getCert()); 
    fluent.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    fluent.withKeySecret(instance.getKeySecret()); 
    fluent.withServerName(instance.getServerName()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ProbeTLSConfigBuilder(ProbeTLSConfig instance) {
    this(instance,false);
  }
  public ProbeTLSConfigBuilder(ProbeTLSConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withCa(instance.getCa()); 
    this.withCert(instance.getCert()); 
    this.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    this.withKeySecret(instance.getKeySecret()); 
    this.withServerName(instance.getServerName()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ProbeTLSConfigFluent<?> fluent;
  Boolean validationEnabled;
  public ProbeTLSConfig build() {
    ProbeTLSConfig buildable = new ProbeTLSConfig(fluent.getCa(),fluent.getCert(),fluent.getInsecureSkipVerify(),fluent.getKeySecret(),fluent.getServerName());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
